"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.isRuleV2 = exports.getRuleV2SerializerFromType = exports.getRuleV2Serializer = void 0;
const additionalSigner_1 = require("./additionalSigner");
const all_1 = require("./all");
const amount_1 = require("./amount");
const any_1 = require("./any");
const namespace_1 = require("./namespace");
const not_1 = require("./not");
const pass_1 = require("./pass");
const pdaMatch_1 = require("./pdaMatch");
const programOwned_1 = require("./programOwned");
const programOwnedList_1 = require("./programOwnedList");
const programOwnedTree_1 = require("./programOwnedTree");
const pubkeyListMatch_1 = require("./pubkeyListMatch");
const pubkeyMatch_1 = require("./pubkeyMatch");
const pubkeyTreeMatch_1 = require("./pubkeyTreeMatch");
const ruleType_1 = require("./ruleType");
const getRuleV2Serializer = (context) => ({
    description: 'RuleV2',
    fixedSize: null,
    maxSize: null,
    serialize: (rule) => (0, exports.getRuleV2SerializerFromType)(context, rule.type).serialize(rule),
    deserialize: (buffer, offset = 0) => {
        const type = buffer[offset];
        const typeAsString = (0, ruleType_1.getRuleTypeV2AsString)(type);
        return (0, exports.getRuleV2SerializerFromType)(context, typeAsString).deserialize(buffer, offset);
    },
});
exports.getRuleV2Serializer = getRuleV2Serializer;
const getRuleV2SerializerFromType = (context, type) => (() => {
    switch (type) {
        case 'AdditionalSigner':
            return (0, additionalSigner_1.getAdditionalSignerRuleV2Serializer)(context);
        case 'All':
            return (0, all_1.getAllRuleV2Serializer)(context);
        case 'Amount':
            return (0, amount_1.getAmountRuleV2Serializer)(context);
        case 'Any':
            return (0, any_1.getAnyRuleV2Serializer)(context);
        // case 'Frequency':
        //   return getFrequencyRuleV2Serializer(context);
        // case 'IsWallet':
        //   return getIsWalletRuleV2Serializer(context);
        case 'Namespace':
            return (0, namespace_1.getNamespaceRuleV2Serializer)(context);
        case 'Not':
            return (0, not_1.getNotRuleV2Serializer)(context);
        case 'Pass':
            return (0, pass_1.getPassRuleV2Serializer)(context);
        case 'PdaMatch':
            return (0, pdaMatch_1.getPdaMatchRuleV2Serializer)(context);
        case 'ProgramOwned':
            return (0, programOwned_1.getProgramOwnedRuleV2Serializer)(context);
        case 'ProgramOwnedList':
            return (0, programOwnedList_1.getProgramOwnedListRuleV2Serializer)(context);
        case 'ProgramOwnedTree':
            return (0, programOwnedTree_1.getProgramOwnedTreeRuleV2Serializer)(context);
        case 'PubkeyListMatch':
            return (0, pubkeyListMatch_1.getPubkeyListMatchRuleV2Serializer)(context);
        case 'PubkeyMatch':
            return (0, pubkeyMatch_1.getPubkeyMatchRuleV2Serializer)(context);
        case 'PubkeyTreeMatch':
            return (0, pubkeyTreeMatch_1.getPubkeyTreeMatchRuleV2Serializer)(context);
        default:
            throw new Error(`Unknown rule type: ${type}`);
    }
})();
exports.getRuleV2SerializerFromType = getRuleV2SerializerFromType;
const isRuleV2 = (rule) => 'type' in rule;
exports.isRuleV2 = isRuleV2;
//# sourceMappingURL=rule.js.map