"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.wrapSerializerInRuleHeaderV2 = exports.getRuleHeaderV2Serializer = void 0;
const umi_1 = require("@metaplex-foundation/umi");
const ruleType_1 = require("./ruleType");
const getRuleHeaderV2Serializer = (context) => {
    const s = context.serializer;
    return s.struct([
        ['type', s.u32()],
        ['length', s.u32()],
    ]);
};
exports.getRuleHeaderV2Serializer = getRuleHeaderV2Serializer;
const wrapSerializerInRuleHeaderV2 = (context, type, serializer) => {
    const typeAsString = (0, ruleType_1.getRuleTypeV2AsString)(type);
    const headerSerializer = (0, exports.getRuleHeaderV2Serializer)(context);
    return {
        description: typeAsString,
        fixedSize: serializer.fixedSize === null ? null : serializer.fixedSize + 8,
        maxSize: serializer.maxSize === null ? null : serializer.maxSize + 8,
        serialize: (rule) => {
            const serializedRule = serializer.serialize(rule);
            const serializedHeader = headerSerializer.serialize({
                type,
                length: serializedRule.length,
            });
            return (0, umi_1.mergeBytes)([serializedHeader, serializedRule]);
        },
        deserialize: (buffer, offset = 0) => {
            const [rule, ruleOffset] = serializer.deserialize(buffer, offset + 8);
            return [{ ...rule, type: typeAsString }, ruleOffset];
        },
    };
};
exports.wrapSerializerInRuleHeaderV2 = wrapSerializerInRuleHeaderV2;
//# sourceMappingURL=ruleHeader.js.map